Package for Statistical Components for Underlying Dimensions.

# Installing
```
pip install scud
```

# Documentation
The documentation can be found [here](https://scud-422a9c.gitlab.io/).


# CONTRIBUTING
You should run
```pre-commit install```
in the repo directory before commiting (if ```pre-commit``` is not installed,
you can pip install it). This will make sure each python file is well
formated and pylint will check the code before any python file is committed. You can check the ```.pre-commit-config.yaml``` file for more details on pylint configuration.


## 🛠 Installation


## ⚡️ Citations

Please cite our work:

Batardière, Bastien, Joon Kwon, Julien Chiquet, and Julien Stoehr (2024).
“Importance sampling based gradient method for dimension reduction in Poisson
Log-Normal model.” In: arXiv. url: https://arxiv.org/abs/2410.00476.
